pub struct EventClient { /* private fields */ }Expand description
The client for SSE.
This is a simple wrapper around reqwest::Client that provides subscription function for SSE.
Implementations
Sourceimpl EventClient
impl EventClient
Sourcepub fn new(client: Client) -> EventClient
pub fn new(client: Client) -> EventClient
Create a new client with the given reqwest client.
use mev_share_sse::EventClient;
let client = EventClient::new(reqwest::Client::new());Sourcepub fn with_max_retries(self, max_retries: u64) -> EventClient
pub fn with_max_retries(self, max_retries: u64) -> EventClient
Set the maximum number of retries.
Sourcepub fn set_max_retries(&mut self, max_retries: u64)
pub fn set_max_retries(&mut self, max_retries: u64)
Set the maximum number of retries.
Sourcepub async fn subscribe<T>(
&self,
endpoint: &str,
) -> Result<EventStream<T>, Error>where
T: DeserializeOwned,
pub async fn subscribe<T>(
&self,
endpoint: &str,
) -> Result<EventStream<T>, Error>where
T: DeserializeOwned,
Subscribe to the MEV-share SSE endpoint.
This connects to the endpoint and returns a stream of T items.
See EventClient::events for a more convenient way to subscribe to Event streams.
Sourcepub async fn subscribe_with_query<T, S>(
&self,
endpoint: &str,
query: S,
) -> Result<EventStream<T>, Error>where
T: DeserializeOwned,
S: Serialize,
pub async fn subscribe_with_query<T, S>(
&self,
endpoint: &str,
query: S,
) -> Result<EventStream<T>, Error>where
T: DeserializeOwned,
S: Serialize,
Subscribe to the MEV-share SSE endpoint with additional query params.
This connects to the endpoint and returns a stream of T items.
See EventClient::events for a more convenient way to subscribe to Event streams.
Sourcepub async fn events(&self, endpoint: &str) -> Result<EventStream<Event>, Error>
pub async fn events(&self, endpoint: &str) -> Result<EventStream<Event>, Error>
Subscribe to a a stream of Events.
This is a convenience function for EventClient::subscribe.
Example
use futures_util::StreamExt;
use mev_share_sse::EventClient;
let client = EventClient::default();
let mut stream = client.events("https://mev-share.flashbots.net").await.unwrap();
while let Some(event) = stream.next().await {
dbg!(&event);
}Sourcepub async fn event_history(
&self,
endpoint: &str,
params: EventHistoryParams,
) -> Result<Vec<EventHistory>, Error>
pub async fn event_history( &self, endpoint: &str, params: EventHistoryParams, ) -> Result<Vec<EventHistory>, Error>
Gets past events that were broadcast via the SSE event stream.
Such as https://mev-share.flashbots.net/api/v1/history.
Example
use mev_share_sse::EventClient;
use mev_share_sse::EventHistoryParams;
let client = EventClient::default();
let params = EventHistoryParams::default();
let history = client.event_history("https://mev-share.flashbots.net/api/v1/history", params).await.unwrap();
dbg!(&history);Sourcepub async fn event_history_info(
&self,
endpoint: &str,
) -> Result<EventHistoryInfo, Error>
pub async fn event_history_info( &self, endpoint: &str, ) -> Result<EventHistoryInfo, Error>
Gets information about the event history endpoint
Such as https://mev-share.flashbots.net/api/v1/history/info.
Example
use mev_share_sse::EventClient;
let client = EventClient::default();
let info = client.event_history_info("https://mev-share.flashbots.net/api/v1/history/info").await.unwrap();
dbg!(&info);Trait Implementations
Sourceimpl Clone for EventClient
impl Clone for EventClient
Sourcefn clone(&self) -> EventClient
fn clone(&self) -> EventClient
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for EventClient
impl Debug for EventClient
Sourceimpl Default for EventClient
impl Default for EventClient
Sourcefn default() -> EventClient
fn default() -> EventClient